//>>built
define("dojo/nls/dojo_it-it",{"dijit/form/nls/validate":{invalidMessage:"Il valore immesso non \u00e8 valido.",missingMessage:"Questo valore \u00e8 obbligatorio.",rangeMessage:"Questo valore \u00e8 fuori dall'intervallo consentito.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",minusSign:"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]",
"decimalFormat-short":"000\u00a0Bln","currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"#,##0.00\u00a0\u00a4",perMille:"\u2030",group:".",percentFormat:"#,##0%","decimalFormat-long":"000 bilioni",decimalFormat:"#,##0.###",decimal:",","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"Scelte precedenti",
nextMessage:"Scelte successive",_localized:{}},"dijit/nls/loading":{loadingState:"Caricamento in corso...",errorState:"Si \u00e8 verificato un errore",_localized:{}},"dijit/nls/common":{buttonOk:"Ok",buttonCancel:"Annulla",buttonSave:"Salva",itemClose:"Chiudi",_localized:{}},"dijit/_editor/nls/commands":{bold:"Grassetto",copy:"Copia",cut:"Taglia","delete":"Elimina",indent:"Rientro",insertHorizontalRule:"Righello orizzontale",insertOrderedList:"Elenco numerato",insertUnorderedList:"Elenco puntato",
italic:"Corsivo",justifyCenter:"Allinea al centro",justifyFull:"Giustifica",justifyLeft:"Allinea a sinistra",justifyRight:"Allinea a destra",outdent:"Annulla rientro",paste:"Incolla",redo:"Ripristina",removeFormat:"Rimuovi formato",selectAll:"Seleziona tutto",strikethrough:"Barrato",subscript:"Pedice",superscript:"Apice",underline:"Sottolinea",undo:"Annulla",unlink:"Rimuovi collegamento",createLink:"Crea collegamento",toggleDir:"Attiva/Disattiva direzione",insertImage:"Inserisci immagine",insertTable:"Inserisci/Modifica tabella",
toggleTableBorder:"Attiva/Disattiva bordo tabella",deleteTable:"Elimina tabella",tableProp:"Propriet\u00e0 tabella",htmlToggle:"Origine HTML",foreColor:"Colore primo piano",hiliteColor:"Colore sfondo",plainFormatBlock:"Stile paragrafo",formatBlock:"Stile paragrafo",fontSize:"Dimensione carattere",fontName:"Nome carattere",tabIndent:"Rientro tabulazione",fullScreen:"Attiva/Disattiva schermo intero",viewSource:"Visualizza origine HTML",print:"Stampa",newPage:"Nuova pagina",systemShortcut:'La azione "${0}" \u00e8 disponibile solo nel browser tramite un tasto di scelta rapida. Utilizzare ${1}.',
ctrlKey:"ctrl+${0}",appleKey:"\u2318${0}",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"piccolissimo",2:"molto piccolo",3:"piccolo",4:"medio",5:"grande",6:"molto grande",7:"grandissimo",fontSize:"Dimensione",fontName:"Carattere",formatBlock:"Formato",serif:"serif","sans-serif":"sans-serif",monospace:"spaziatura fissa",cursive:"corsivo",fantasy:"fantasy",noFormat:"Nessuna",p:"Paragrafo",h1:"Intestazione",h2:"Sottointestazione",h3:"Sottointestazione secondaria",pre:"Preformattato",_localized:{}},
"dojox/editor/plugins/nls/latinEntities":{iexcl:"punto esclamativo capovolto",cent:"simbolo del centesimo",pound:"simbolo della sterlina",curren:"simbolo di valuta",yen:"simbolo dello yen\nsimbolo dello yuan",brvbar:"barra interrotta\nbarra verticale interrotta",sect:"simbolo di sezione",uml:"dieresi\ndieresi con spazio",copy:"simbolo del copyright",ordf:"indicatore ordinale femminile",laquo:"virgolette doppie angolari indicanti a sinistra\nguillemet indicante a sinistra",not:"simbolo di negazione",
shy:"trattino debole\ntrattino discrezionale",reg:"simbolo di registrazione\nsimbolo di marchio registrato",macr:"macron\nmacron con spaziatura\nlinea orizzontale superiore\nbarra sovrapposta APL",deg:"simbolo dei gradi",plusmn:"segno pi\u00f9-meno\nsegno pi\u00f9 o meno",sup2:"esponente due\nnumero due in esponente\nal quadrato",sup3:"esponente tre\nnumero tre in esponente\nal cubo",acute:"accento acuto\nacuto con spaziatura",micro:"simbolo di micro",para:"simbolo pilcrow\nsimbolo di paragrafo",
middot:"punto in mezzo\nvirgola georgiana\npunto centrale greco",cedil:"cediglia\ncediglia con spazio",sup1:"esponente uno\nnumero uno in esponente",ordm:"indicatore ordinale maschile",raquo:"virgolette doppie angolari indicanti a destra\nguillemet indicante a destra",frac14:"frazione semplice un quarto\nfrazione un quarto",frac12:"frazione semplice un mezzo\nfrazione un mezzo",frac34:"frazione semplice tre quarti\nfrazione tre quarti",iquest:"punto interrogativo invertito\npunto interrogativo rovesciato",
Agrave:"lettera latina A maiuscola con accento grave\nlettera latina A maiuscola grave",Aacute:"lettera latina A maiuscola con accento acuto",Acirc:"lettera latina A maiuscola con accento circonflesso",Atilde:"lettera latina A maiuscola con tilde",Auml:"lettera latina A maiuscola con dieresi",Aring:"lettera latina A maiuscola con sormontata da anello\nlettera latina A maiuscola anellata",AElig:"lettera latina AE maiuscola\nlegatura latina maiuscola AE",Ccedil:"lettera latina C maiuscola con cediglia",
Egrave:"lettera latina E maiuscola con accento grave",Eacute:"lettera latina E maiuscola con accento acuto",Ecirc:"lettera latina E maiuscola con accento circonflesso",Euml:"lettera latina E maiuscola con dieresi",Igrave:"lettera latina I maiuscola con accento grave",Iacute:"lettera latina I maiuscola con accento acuto",Icirc:"lettera latina I maiuscola con accento circonflesso",Iuml:"lettera latina I maiuscola con dieresi",ETH:"lettera latina ETH maiuscola",Ntilde:"lettera latina N maiuscola con tilde",
Ograve:"lettera latina O maiuscola con accento grave",Oacute:"lettera latina O maiuscola con accento acuto",Ocirc:"lettera latina O maiuscola con accento circonflesso",Otilde:"lettera latina O maiuscola con tilde",Ouml:"lettera latina O maiuscola con dieresi",times:"segno di moltiplicazione",Oslash:"lettera latina O maiuscola con barra obliqua\nlettera latina O maiuscola barrata",Ugrave:"lettera latina U maiuscola con accento grave",Uacute:"lettera latina U maiuscola con accento acuto",Ucirc:"lettera latina U maiuscola con accento circonflesso",
Uuml:"lettera latina U maiuscola con dieresi",Yacute:"lettera latina Y maiuscola con accento acuto",THORN:"lettera latina THORN maiuscola",szlig:"lettera latina s minuscola sonoraesse-zeta",agrave:"lettera latina a minuscola con accento grave\nlettera latina a minuscola grave",aacute:"lettera latina a minuscola con accento acuto",acirc:"lettera latina a minuscola con accento circonflesso",atilde:"lettera latina a minuscola con tilde",auml:"lettera latina a minuscola con dieresi",aring:"lettera latina a minuscola sormontata da anello\nlettera latina a minuscola anellata",
aelig:"lettera latina ae minuscola\nlegatura latina minuscola ae",ccedil:"lettera latina c minuscola con cediglia",egrave:"lettera latina e minuscola con accento grave",eacute:"lettera latina e minuscola con accento acuto",ecirc:"lettera latina e minuscola con accento circonflesso",euml:"lettera latina e minuscola con dieresi",igrave:"lettera latina i minuscola con accento grave",iacute:"lettera latina i minuscola con accento acuto",icirc:"lettera latina i minuscola con accento circonflesso",iuml:"lettera latina i minuscola con dieresi",
eth:"lettera latina eth minuscola",ntilde:"lettera latina n minuscola con tilde",ograve:"lettera latina o minuscola con accento grave",oacute:"lettera latina o minuscola con accento acuto",ocirc:"lettera latina o minuscola con accento circonflesso",otilde:"lettera latina o minuscola con tilde",ouml:"lettera latina o minuscola con dieresi",divide:"segno di divisione",oslash:"lettera latina o minuscola con barra obliqua1nlettera latina o minuscola barrata",ugrave:"lettera latina u minuscola con accento grave",
uacute:"lettera latina u minuscola con accento acuto",ucirc:"lettera latina u minuscola con accento circonflesso",uuml:"lettera latina u minuscola con dieresi",yacute:"lettera latina y minuscola con accento acuto",thorn:"lettera latina thorn minuscola",yuml:"lettera latina y minuscola con dieresi",fnof:"f latina minuscola con uncino\nfunzione\nfiorino",Alpha:"lettera greca maiuscola alpha",Beta:"lettera greca maiuscola beta",Gamma:"lettera greca maiuscola gamma",Delta:"lettera greca maiuscola delta",
Epsilon:"lettera greca maiuscola epsilon",Zeta:"lettera greca maiuscola zeta",Eta:"lettera greca maiuscola eta",Theta:"lettera greca maiuscola theta",Iota:"lettera greca maiuscola iota",Kappa:"lettera greca maiuscola kappa",Lambda:"lettera greca maiuscola lambda",Mu:"lettera greca maiuscola mu",Nu:"lettera greca maiuscola nu",Xi:"lettera greca maiuscola xi",Omicron:"lettera greca maiuscola omicron",Pi:"lettera greca maiuscola pi",Rho:"lettera greca maiuscola rho",Sigma:"lettera greca maiuscola sigma",
Tau:"lettera greca maiuscola tau",Upsilon:"lettera greca maiuscola upsilon",Phi:"lettera greca maiuscola phi",Chi:"lettera greca maiuscola chi",Psi:"lettera greca maiuscola psi",Omega:"lettera greca maiuscola omega",alpha:"lettera greca maiuscola alpha",beta:"lettera greca minuscola beta",gamma:"lettera greca minuscola gamma",delta:"lettera greca minuscola delta",epsilon:"lettera greca minuscola epsilon",zeta:"lettera greca minuscola zeta",eta:"lettera greca minuscola eta",theta:"lettera greca minuscola theta",
iota:"lettera greca minuscola iota",kappa:"lettera greca minuscola kappa",lambda:"lettera greca minuscola lambda",mu:"lettera greca minuscola mu",nu:"lettera greca minuscola nu",xi:"lettera greca minuscola xi",omicron:"lettera greca minuscola omicron",pi:"lettera greca minuscola pi",rho:"lettera greca minuscola rho",sigmaf:"lettera greca minuscola sigma finale",sigma:"lettera greca minuscola sigma",tau:"lettera greca minuscola tau",upsilon:"lettera greca minuscola upsilon",phi:"lettera greca minuscola phi",
chi:"lettera greca minuscola chi",psi:"lettera greca minuscola psi",omega:"lettera greca minuscola omega",thetasym:"simbolo della lettera greca minuscola theta",upsih:"simbolo della upsilon greca con uncino",piv:"simbolo di pi greco",bull:"pallino\npiccolo cerchio nero",hellip:"puntini di sospensione\ntre puntini di guida",prime:"apice\nminuti\npiedi",Prime:"doppio apice\nsecondi\npollici",oline:"linea sopra\noverscore con spazio",frasl:"barra obliqua di frazione",weierp:"P maiuscola scritta a mano\ninsieme potenza\np di Weierstrass",
image:"I maiuscola gotica\nelemento immaginario",real:"R maiuscola gotica\nsimbolo di elemento reale",trade:"simbolo di marchio commerciale",alefsym:"simbolo alef\nprimo cardinale transfinito",larr:"freccia verso sinistra",uarr:"freccia verso l'alto",rarr:"freccia verso destra",darr:"freccia verso il basso",harr:"freccia sinistra destra",crarr:"freccia verso il basso con angolo a sinistra\nritorno a capo",lArr:"doppia freccia verso sinistra",uArr:"doppia freccia verso l'alto",rArr:"doppia freccia verso destra",
dArr:"doppia freccia verso il basso",hArr:"doppia freccia sinistra destra",forall:"per tutti",part:"differenziale parziale",exist:"esiste",empty:"insieme vuoto\ninsieme nullo\ndiametro",nabla:"nabla\ndifferenza retrograda",isin:"elemento di",notin:"non un elemento di",ni:"contiene come membro",prod:"prodotto n-ario\nsegno di prodotto",sum:"sommatoria n-aria",minus:"segno meno",lowast:"operatore asterisco",radic:"radice quadrata\nsegno di radice",prop:"proporzionale a",infin:"infinito",ang:"angolo",
and:"and logico\ncuneo",or:"o logico\nvi",cap:"intersezione\nberretto",cup:"unione\ncoppa","int":"integrale",there4:"pertanto",sim:"operatore tilde\nvaria con\nsimile a",cong:"approssimativamente uguale a",asymp:"quasi uguale a\nasintotico a",ne:"non uguale a",equiv:"identico a",le:"minore di o uguale a",ge:"maggiore di o uguale a",sub:"sottoinsieme di",sup:"sovrainsieme di",nsub:"non un sottoinsieme di",sube:"sottoinsieme di o uguale a",supe:"sovrainsieme di o uguale a",oplus:"pi\u00f9 cerchiato\nsomma diretta",
otimes:"per cerchiato\nprodotto vettoriale",perp:"puntina in su\nortogonale a\nperpendicolare",sdot:"operatore punto",lceil:"soffitto sinistro\ngradino in su APL",rceil:"soffitto destro",lfloor:"pavimento sinistro\ngradino in gi\u00f9 APL",rfloor:"pavimento destro",lang:"parentesi angolare sinistra",rang:"parentesi angolare destra",loz:"losanga",spades:"seme di picche nero",clubs:"seme di fiori nero\ntrifoglio",hearts:"seme di cuori nero\ninnamorato",diams:"seme di quadri nero",OElig:"legatura latina OE maiuscola",
oelig:"legatura latina oe minuscola",Scaron:"lettera latina S maiuscola con caron",scaron:"lettera latina s minuscola con caron",Yuml:"lettera latina Y maiuscola con dieresi",circ:"lettera modificatrice accento circonflesso",tilde:"tilde piccola",ensp:"spazio en",emsp:"spazio em",thinsp:"spazio finissimo",zwnj:"non-congiuntore di larghezza zero",zwj:"congiuntore di larghezza zero",lrm:"segno da-sinistra-a-destra",rlm:"segno da-destra-a-sinistra",ndash:"trattino en",mdash:"trattino em",lsquo:"virgoletta sinistra singola",
rsquo:"virgoletta destra singola",sbquo:"virgoletta singola in basso a destra",ldquo:"virgolette doppie sinistre",rdquo:"virgolette doppie destre",bdquo:"virgolette doppie in basso a destra",dagger:"croce latina",Dagger:"croce latina doppia",permil:"segno di per mille",lsaquo:"virgoletta angolare singola rivolta a sinistra",rsaquo:"virgoletta angolare singola rivolta a destra",euro:"simbolo dell'euro",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"Inserisci simbolo",_localized:{}},
"dojo/nls/colors":{aliceblue:"bianco ghiaccio",antiquewhite:"rosa antico",aqua:"verde acqua",aquamarine:"acquamarina",azure:"azure",beige:"beige",bisque:"terracotta",black:"nero",blanchedalmond:"beige 2",blue:"blu",blueviolet:"violetto bluastro",brown:"marrone",burlywood:"legno massiccio",cadetblue:"verde petrolio",chartreuse:"verde brillante",chocolate:"cioccolato",coral:"corallo",cornflowerblue:"blu fiordaliso",cornsilk:"crema",crimson:"rosso scarlatto",cyan:"ciano",darkblue:"blu scuro",darkcyan:"celeste scuro",
darkgoldenrod:"ocra scuro",darkgray:"grigio scuro",darkgreen:"verde scuro",darkgrey:"grigio scuro",darkkhaki:"cachi scuro",darkmagenta:"magenta scuro",darkolivegreen:"verde oliva scuro",darkorange:"arancione scuro",darkorchid:"orchidea scuro",darkred:"rosso scuro",darksalmon:"salmone scuro",darkseagreen:"verde acqua scuro",darkslateblue:"blu ardesia scuro",darkslategray:"grigio ardesia scuro",darkslategrey:"grigio ardesia scuro",darkturquoise:"turchese scuro",darkviolet:"viola scuro",deeppink:"ciclamino",
deepskyblue:"azzurro intenso",dimgray:"grigio tenue",dimgrey:"grigio tenue",dodgerblue:"dodger blue",firebrick:"mattone",floralwhite:"bianco grigio",forestgreen:"verde pino scuro",fuchsia:"fucsia",gainsboro:"gainsboro",ghostwhite:"bianco gesso",gold:"oro",goldenrod:"dorato",gray:"grigio",green:"verde",greenyellow:"verde-giallo",grey:"grigio",honeydew:"miele",hotpink:"rosa acceso",indianred:"terra indiana",indigo:"indaco",ivory:"avorio",khaki:"cachi",lavender:"lavanda",lavenderblush:"lavanda rosa",
lawngreen:"verde brillante chiaro",lemonchiffon:"lemon chiffon",lightblue:"blu chiaro",lightcoral:"corallo chiaro",lightcyan:"ciano chiaro",lightgoldenrodyellow:"giallo dorato chiaro",lightgray:"grigio chiaro",lightgreen:"verde chiaro",lightgrey:"grigio chiaro",lightpink:"rosa chiaro",lightsalmon:"salmone chiaro",lightseagreen:"verde acqua chiaro",lightskyblue:"azzurro chiaro",lightslategray:"grigio ardesia chiaro",lightslategrey:"grigio ardesia chiaro",lightsteelblue:"blu acciaio chiaro",lightyellow:"giallo chiaro",
lime:"lime",limegreen:"verde lime",linen:"lino",magenta:"magenta",maroon:"Bordeaux",mediumaquamarine:"acquamarina medio",mediumblue:"blu medio",mediumorchid:"orchidea medio",mediumpurple:"viola medio",mediumseagreen:"verde acqua medio",mediumslateblue:"blu ardesia medio",mediumspringgreen:"verde brillante medio",mediumturquoise:"turchese medio",mediumvioletred:"violetto rosso medio",midnightblue:"blu notte",mintcream:"bianco nuvola",mistyrose:"rosa pallido",moccasin:"mocassino",navajowhite:"sabbia",
navy:"blu scuro",oldlace:"mandorla",olive:"verde oliva",olivedrab:"verde bottiglia",orange:"arancione",orangered:"vermiglio",orchid:"orchidea",palegoldenrod:"dorato pallido",palegreen:"verde pallido",paleturquoise:"turchese pallido",palevioletred:"violetto rosso pallido",papayawhip:"papaya",peachpuff:"pesche",peru:"per\u00f9",pink:"rosa",plum:"prugna",powderblue:"azzurro polvere",purple:"viola",red:"rosso",rosybrown:"caff\u00e8 latte",royalblue:"royal blue",saddlebrown:"cacao",salmon:"salmone",sandybrown:"argilla",
seagreen:"verde acqua",seashell:"sabbia rosa",sienna:"terra di siena",silver:"argento",skyblue:"azzurro",slateblue:"blu ardesia",slategray:"grigio ardesia",slategrey:"grigio ardesia",snow:"neve",springgreen:"verde brillante",steelblue:"blu brillante",tan:"tan",teal:"verde acqua",thistle:"rosa cenere",tomato:"pomodoro",transparent:"trasparente",turquoise:"turchese",violet:"violetto",wheat:"tabacco",white:"bianco",whitesmoke:"bianco fumo",yellow:"giallo",yellowgreen:"giallo verde",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"r",
greenLabel:"v",blueLabel:"b",hueLabel:"t",saturationLabel:"s",valueLabel:"v",degLabel:"\u00b0",hexLabel:"hex",huePickerTitle:"Selettore tonalit\u00e0",saturationPickerTitle:"Selettore saturazione",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"Inserisci tabella",modifyTableTitle:"Modifica tabella",rows:"Righe:",columns:"Colonne:",align:"Allinea:",cellPadding:"Riempimento cella:",cellSpacing:"Spaziatura celle:",tableWidth:"Larghezza tabella:",backgroundColor:"Colore sfondo:",
borderColor:"Colore bordo:",borderThickness:"Spessore bordo:",percent:"percento",pixels:"pixel","default":"predefinito",left:"sinistra",center:"centro",right:"destra",buttonSet:"Imposta",buttonInsert:"Inserisci",buttonCancel:"Annulla",selectTableLabel:"Seleziona tabella",insertTableRowBeforeLabel:"Inserisci riga prima",insertTableRowAfterLabel:"Inserisci riga dopo",insertTableColumnBeforeLabel:"Aggiungi colonna prima",insertTableColumnAfterLabel:"Aggiungi colonna dopo",deleteTableRowLabel:"Elimina riga",
deleteTableColumnLabel:"Elimina colonna",colorTableCellTitle:"Cella tabella colore sfondo",tableContextMenuTitle:"Menu di contesto tabella",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"Incolla da Word",instructions:"Incollare i contenuti da Word nella seguente casella di testo. Quando si \u00e8 deciso quali contenuti inserire, fare clic sul pulsante incolla. Per interrompere l'inserimento del testo premere il pulsante annulla.",_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"Inserisci ancoraggio",
title:"Propriet\u00e0 ancoraggio",anchor:"Nome:",text:"Descrizione:",set:"Imposta",cancel:"Annulla",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Blockquote",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"Inserisci immagine",url:"Immagine",browse:"Sfoglia...",text:"Descrizione",set:"Inserisci",invalidMessage:"Tipo file immagine non valido",prePopuTextUrl:"Immettere un URL immagine",prePopuTextBrowse:" o selezionare un file locale.",_localized:{}},"dojo/cldr/nls/gregorian":{"dateFormatItem-Ehm":"E h.mm a",
"days-standAlone-short":"dom lun mar mer gio ven sab".split(" "),"months-format-narrow":"GFMAMGLASOND".split(""),"field-second-relative+0":"ora","quarters-standAlone-narrow":["1","2","3","4"],"field-weekday":"giorno della settimana","dateFormatItem-yQQQ":"QQQ y","dateFormatItem-yMEd":"E d/M/y","field-wed-relative+0":"questo mercoled\u00ec","field-wed-relative+1":"mercoled\u00ec prossimo","dateFormatItem-GyMMMEd":"E d MMM y G","dateFormatItem-MMMEd":"E d MMM",eraNarrow:["aC","BCE","dC","CE"],"field-tue-relative+-1":"marted\u00ec scorso",
"days-format-short":"dom lun mar mer gio ven sab".split(" "),"dateTimeFormats-appendItem-Day-Of-Week":"{0} {1}","dateFormat-long":"dd MMMM y","field-fri-relative+-1":"venerd\u00ec scorso","field-wed-relative+-1":"mercoled\u00ec scorso","months-format-wide":"gennaio febbraio marzo aprile maggio giugno luglio agosto settembre ottobre novembre dicembre".split(" "),"dateTimeFormat-medium":"{1} {0}","dayPeriods-format-wide-pm":"PM","dateFormat-full":"EEEE d MMMM y","field-thu-relative+-1":"gioved\u00ec scorso",
"dateFormatItem-Md":"d/M","dayPeriods-format-abbr-am":"AM","dateTimeFormats-appendItem-Second":"{0} ({2}: {1})","dayPeriods-format-wide-noon":"noon","dateFormatItem-yMd":"d/M/y","field-era":"era","dateFormatItem-yM":"M/y","months-standAlone-wide":"Gennaio Febbraio Marzo Aprile Maggio Giugno Luglio Agosto Settembre Ottobre Novembre Dicembre".split(" "),"timeFormat-short":"HH:mm","quarters-format-wide":["1\u00ba trimestre","2\u00ba trimestre","3\u00ba trimestre","4\u00ba trimestre"],"dateFormatItem-yQQQQ":"QQQQ y",
"timeFormat-long":"HH:mm:ss z","field-year":"anno","dateFormatItem-yMMM":"MMM y","dateTimeFormats-appendItem-Era":"{1} {0}","field-hour":"ora","months-format-abbr":"gen feb mar apr mag giu lug ago set ott nov dic".split(" "),"field-sat-relative+0":"questo sabato","field-sat-relative+1":"sabato prossimo","timeFormat-full":"HH:mm:ss zzzz","dateTimeFormats-appendItem-Week":"{0} ({2}: {1})","field-day-relative+0":"oggi","field-thu-relative+0":"questo gioved\u00ec","field-day-relative+1":"domani","field-thu-relative+1":"gioved\u00ec prossimo",
"dateFormatItem-GyMMMd":"d MMM y G","dateFormatItem-H":"HH","months-standAlone-abbr":"gen feb mar apr mag giu lug ago set ott nov dic".split(" "),"quarters-format-abbr":["T1","T2","T3","T4"],"quarters-standAlone-wide":["Primo trimestre","Secondo trimestre","Terzo trimestre","Quarto trimestre"],"dateFormatItem-Gy":"y G","dateFormatItem-M":"L","days-standAlone-wide":"Domenica Luned\u00ec Marted\u00ec Mercoled\u00ec Gioved\u00ec Venerd\u00ec Sabato".split(" "),"dayPeriods-format-abbr-noon":"noon","timeFormat-medium":"HH:mm:ss",
"field-sun-relative+0":"questa domenica","dateFormatItem-Hm":"HH:mm","field-sun-relative+1":"domenica prossima","quarters-standAlone-abbr":["T1","T2","T3","T4"],eraAbbr:["aC","BCE","dC","CE"],"field-minute":"minuto","field-dayperiod":"periodo del giorno","days-standAlone-abbr":"dom lun mar mer gio ven sab".split(" "),"dateFormatItem-d":"d","dateFormatItem-ms":"mm:ss","quarters-format-narrow":["1","2","3","4"],"field-day-relative+-1":"ieri","dateTimeFormat-long":"{1} {0}","dayPeriods-format-narrow-am":"m.",
"dateFormatItem-h":"hh a","dateFormatItem-MMMd":"d MMM","dateFormatItem-MEd":"E d/M","dateTimeFormat-full":"{1} {0}","field-fri-relative+0":"questo venerd\u00ec","field-fri-relative+1":"venerd\u00ec prossimo","field-day":"giorno","days-format-wide":"domenica luned\u00ec marted\u00ec mercoled\u00ec gioved\u00ec venerd\u00ec sabato".split(" "),"field-zone":"fuso orario","months-standAlone-narrow":"GFMAMGLASOND".split(""),"dateFormatItem-y":"y","dateTimeFormats-appendItem-Day":"{0} ({2}: {1})","field-year-relative+-1":"anno scorso",
"field-month-relative+-1":"mese scorso","dateTimeFormats-appendItem-Year":"{1} {0}","dateFormatItem-hm":"hh:mm a","dateTimeFormats-appendItem-Hour":"{0} ({2}: {1})","dayPeriods-format-abbr-pm":"PM","days-format-abbr":"dom lun mar mer gio ven sab".split(" "),eraNames:["a.C.","BCE","d.C.","CE"],"dateFormatItem-yMMMd":"d MMM y","days-format-narrow":"DLMMGVS".split(""),"field-month":"mese","days-standAlone-narrow":"DLMMGVS".split(""),"dateFormatItem-MMM":"LLL","field-tue-relative+0":"questo marted\u00ec",
"dateTimeFormats-appendItem-Quarter":"{0} ({2}: {1})","field-tue-relative+1":"marted\u00ec prossimo","dayPeriods-format-wide-am":"AM","dateTimeFormats-appendItem-Month":"{0} ({2}: {1})","dateTimeFormats-appendItem-Minute":"{0} ({2}: {1})","dateFormatItem-EHm":"E HH.mm","field-mon-relative+0":"questo luned\u00ec","field-mon-relative+1":"luned\u00ec prossimo","dateFormat-short":"dd/MM/yy","dateFormatItem-EHms":"E HH:mm:ss","dateFormatItem-Ehms":"E h:mm:ss a","dayPeriods-format-narrow-noon":"n","field-second":"secondo",
"field-sat-relative+-1":"sabato scorso","dateFormatItem-yMMMEd":"E d MMM y","field-sun-relative+-1":"domenica scorsa","field-month-relative+0":"questo mese","field-month-relative+1":"mese prossimo","dateTimeFormats-appendItem-Timezone":"{0} {1}","dateFormatItem-Ed":"E d","field-week":"settimana","dateFormat-medium":"dd/MMM/y","field-week-relative+-1":"settimana scorsa","field-year-relative+0":"quest'anno","field-year-relative+1":"anno prossimo","dayPeriods-format-narrow-pm":"p.","dateTimeFormat-short":"{1} {0}",
"dateFormatItem-Hms":"HH:mm:ss","dateFormatItem-hms":"hh:mm:ss a","dateFormatItem-GyMMM":"MMM y G","field-mon-relative+-1":"luned\u00ec scorso","field-week-relative+0":"questa settimana","field-week-relative+1":"settimana prossima","field-day-relative+2":"dopodomani","field-day-relative+-2":"l'altro ieri","dateFormatItem-yMMMM":"MMMM y",_localized:{}}});
//# sourceMappingURL=dojo_it-it.js.map